## Overview

Top level directory for Intel® Threading Building Blocks (Intel® TBB).

## Common directories

include
  Include files required for compiling code that uses the library.
examples
  Examples of how to use the library.
python
  Python* API for Intel TBB.

## Intel TBB source package

To build Intel TBB, use the top-level Makefile; see also the build directions. To port Intel TBB to a new platform, operating system or architecture, see the porting directions.

### Files

Makefile
  Top-level Makefile for Intel TBB. See also the build directions.

### Directories

src
  Source code for the library.
build, jni
  Internal Makefile infrastructure for Intel TBB. Do not use directly; see the build directions.

## Intel TBB binary package

### Directories

doc
  Documentation for the library.
bin
  Start-up scripts for sourcing library for Linux* OS and macOS*. For Windows* OS: start-up scripts and dynamic-link libraries.
lib
  Platform-specific binary files for the library.

Copyright © 2005-2018 Intel Corporation. All Rights Reserved.

Intel is a registered trademark or trademark of Intel Corporation or its subsidiaries in the United States and other countries.

* Other names and brands may be claimed as the property of others.